pub enum OpCode {
Continue,
Text,
Binary,
ReservedNonControl,
Close,
Ping,
Pong,
ReservedControl,
}
Defines the interpretation of the “Payload data”. If an unknown
opcode is received, the receiving endpoint MUST Fail the
WebSocket Connection. The following values are defined.
- x0 denotes a continuation frame
- x1 denotes a text frame
- x2 denotes a binary frame
- x3-7 are reserved for further non-control frames
- x8 denotes a connection close
- x9 denotes a ping
- xA denotes a pong
- xB-F are reserved for further control frames
- x0 denotes a continuation frame
- x2 denotes a binary frame
- x3-7 are reserved for further non-control frames
- x8 denotes a connection close
- xB-F are reserved for further control frames
get corresponding u8 value
check is close type frame
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
This method tests for self and other values to be equal, and is used
by ==.
This method tests for !=. The default implementation is almost always
sufficient, and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.