pub struct Frame(_);Expand description
websocket data frame
Implementations
sourceimpl Frame
impl Frame
pub fn fin(&self) -> bool
pub fn set_fin(&mut self, val: bool)
pub fn rsv1(&self) -> bool
pub fn set_rsv1(&mut self, val: bool)
pub fn rsv2(&self) -> bool
pub fn set_rsv2(&mut self, val: bool)
pub fn rsv3(&self) -> bool
pub fn set_rsv3(&mut self, val: bool)
pub fn mask(&self) -> bool
sourcepub fn set_mask(&mut self, mask: bool)
pub fn set_mask(&mut self, mask: bool)
NOTE if change mask bit after setting payload you need to set payload again to adjust data frame
pub fn payload_len(&self) -> u64
pub fn masking_key(&self) -> Option<[u8; 4]>
pub fn set_masking_key(&mut self) -> Option<[u8; 4]>
sourcepub fn payload_data_unmask(&self) -> Bytes
pub fn payload_data_unmask(&self) -> Bytes
return unmask(if masked) payload data
pub fn payload_data(&self) -> &[u8]ⓘNotable traits for &'_ [u8]impl<'_> Read for &'_ [u8]impl<'_> Write for &'_ mut [u8]
sourceimpl Frame
impl Frame
helper construct methods
pub fn new_with_opcode(opcode: OpCode) -> Self
pub fn new_with_payload(opcode: OpCode, payload: &[u8]) -> Self
sourcepub fn set_payload(&mut self, payload: &[u8])
pub fn set_payload(&mut self, payload: &[u8])
set frame payload
NOTE! avoid calling this method multi times, since it need to calculate mask every time
pub fn as_bytes(&self) -> &[u8]ⓘNotable traits for &'_ [u8]impl<'_> Read for &'_ [u8]impl<'_> Write for &'_ mut [u8]