Struct ws_tool::ClientBuilder
source · [−]pub struct ClientBuilder { /* private fields */ }Implementations
sourceimpl ClientBuilder
impl ClientBuilder
sourceimpl ClientBuilder
impl ClientBuilder
pub fn new<S: ToString>(uri: S) -> Self
sourcepub fn protocols(self, protocols: Vec<String>) -> Self
pub fn protocols(self, protocols: Vec<String>) -> Self
set extension in handshake http header
NOTE it will clear protocols set by protocol method
sourcepub fn extensions(self, extensions: Vec<String>) -> Self
pub fn extensions(self, extensions: Vec<String>) -> Self
set extension in handshake http header
NOTE it will clear protocols set by protocol method
pub fn header<K: ToString, V: ToString>(self, name: K, value: V) -> Self
pub fn headers(self, headers: HashMap<String, String>) -> Self